@@ -55,10 +55,10 @@
 
 
 struct gpe_icon my_icons[] = {
-	{"irda-on", "/usr/share/pixmaps/irda-on-16.png"},
-	{"irda-off", "/usr/share/pixmaps/irda-16.png"},
-	{"irda", "/usr/share/pixmaps/irda.png"},
-	{NULL}
+	{"irda-on", PREFIX "/share/pixmaps/irda-on-16.png"},
+	{"irda-off", PREFIX "/share/pixmaps/irda-16.png"},
+	{"irda", PREFIX "/share/pixmaps/irda.png"},
+	{NULL, NULL}
 };
 
 static GtkWidget *icon;
@@ -363,10 +363,8 @@ tx_file_select (char *filename, gpointer data)
 void
 exec_file_abort ()
 {
-	gdk_threads_enter ();
 	gtk_widget_destroy (dlgStatus);
 	lStatus = NULL;
-	gdk_threads_leave ();
 }
 
 
@@ -376,9 +374,9 @@ tx_file_cancel (gpointer data)
 	scan_thread =
 		g_thread_create ((GThreadFunc) exec_file_abort, NULL, FALSE,
 				 NULL);
-
 	if (scan_thread == NULL)
 		gpe_perror_box (_("Unable to start file transmit."));
+	
 }
 
 
@@ -408,11 +406,11 @@ do_send_file (void)
 	}
 	else
 	{
-		gdk_threads_enter ();
+		gdk_threads_enter();
 		ask_user_a_file (getenv ("HOME"),
 				 _("Select file to transmit"), tx_file_select,
 				 tx_file_cancel, NULL);
-		gdk_threads_leave ();
+		gdk_threads_leave();
 		printf ("exit do send...\n");
 	}
 }
@@ -442,7 +440,7 @@ do_import_file(GtkWidget *dlg,gint response,char *filename)
 							  GTK_DIALOG_DESTROY_WITH_PARENT,
 							  GTK_MESSAGE_INFO,
 							  GTK_BUTTONS_CLOSE,
-							  _("VCARD was imported successfully."));
+							  _("vCard was imported successfully."));
 			break;
 		default:
 			dlg = gtk_message_dialog_new
@@ -450,7 +448,7 @@ do_import_file(GtkWidget *dlg,gint response,char *filename)
 				 GTK_DIALOG_DESTROY_WITH_PARENT,
 				 GTK_MESSAGE_ERROR,
 				 GTK_BUTTONS_CLOSE,
-				 _("Import of VCARD failed."));
+				 _("Import of vCard failed."));
 			break;
 		}
 		gtk_dialog_run (GTK_DIALOG (dlg));
@@ -479,11 +477,10 @@ check_file_import (char *filename)
 					      GTK_DIALOG_DESTROY_WITH_PARENT | GTK_DIALOG_MODAL,
 					      GTK_MESSAGE_QUESTION,
 					      GTK_BUTTONS_YES_NO,
-					      _
-					      ("The file %s looks like a VCARD, "
-					       "may i import it?"), filename);
+					      _("File '%s' looks like a vCard, "
+					       "do you want to import it?"), filename);
 		
-		 g_signal_connect_after (GTK_OBJECT (dlg), "response",
+		g_signal_connect_after (GTK_OBJECT (dlg), "response",
                            G_CALLBACK (do_import_file),
                            filename);
 		gtk_widget_show_all(dlg);
@@ -539,8 +536,7 @@ do_receive_file (void)
 		{
 			gdk_threads_enter ();
 			ts = g_strdup_printf ("%s %s",
-					      _
-					      ("Received file"),
+					      _("Received file"),
 					      str_last_filename);
 			gtk_label_set_text (GTK_LABEL (lTStatus), ts);
 			free (ts);
@@ -640,6 +636,8 @@ show_control (void)
 {
 	GtkWidget *img;
 	GtkWidget *tw, *hb;
+	gchar *str;
+	
 	if (control_window == NULL)
 	{
 		GtkWidget *hsep = gtk_hseparator_new ();
@@ -665,10 +663,13 @@ show_control (void)
 		gtk_misc_set_alignment (GTK_MISC (lCHint), 0, 0.0);
 		lSaddr = gtk_label_new (NULL);
 		gtk_misc_set_alignment (GTK_MISC (lSaddr), 0, 0.5);
+		str = g_strdup_printf("<b>%s</b>",_("Peer Information"));
+		gtk_label_set_markup (GTK_LABEL(lcPeer), str);
+		g_free(str);			  
+		str = g_strdup_printf("<b>%s</b>",_("Peer Actions"));
 		gtk_label_set_markup (GTK_LABEL
-				      (lcPeer), _("<b>Peer Information</b>"));
-		gtk_label_set_markup (GTK_LABEL
-				      (lcActions), _("<b>Peer Actions</b>"));
+				      (lcActions), str);
+		g_free(str);			  
 		hb = gtk_hbox_new (FALSE, gpe_get_boxspacing ());
 		img = gtk_image_new_from_stock
 			(GTK_STOCK_GO_UP, GTK_ICON_SIZE_BUTTON);
@@ -859,6 +860,29 @@ clicked (GtkWidget * w, GdkEventButton * ev)
 			gpe_popup_menu_position, w, ev->button, ev->time);
 }
 
+/* handle resizing */
+gboolean 
+external_event(GtkWindow *window, GdkEventConfigure *event, gpointer user_data)
+{
+  GdkBitmap *bitmap;
+  GdkPixbuf *sbuf, *dbuf;
+  int size;
+
+  if (event->type == GDK_CONFIGURE)
+  {
+    size = (event->width > event->height) ? event->height : event->width;
+    sbuf = gpe_find_icon (radio_is_on ? "irda-on" : "irda-off");
+    dbuf = gdk_pixbuf_scale_simple(sbuf,size, size,GDK_INTERP_HYPER);
+    gdk_pixbuf_render_pixmap_and_mask (dbuf, NULL, &bitmap, 128);
+    gtk_widget_shape_combine_mask (GTK_WIDGET(window), NULL, 1, 0);
+    gtk_widget_shape_combine_mask (GTK_WIDGET(window), bitmap, 1, 0);
+    gdk_bitmap_unref (bitmap);
+    gtk_image_set_from_pixbuf(GTK_IMAGE(icon),dbuf);
+	/* make sure we want to resize all the time */
+	gtk_widget_set_size_request(GTK_WIDGET(window),size+1,size);
+  }
+  return FALSE;
+}
 
 int
 main (int argc, char *argv[])
@@ -873,6 +897,8 @@ main (int argc, char *argv[])
 	gdk_threads_init ();
 	if (gpe_application_init (&argc, &argv) == FALSE)
 		exit (1);
+	if (gpe_load_icons (my_icons) == FALSE)
+		exit (1);
 	
 	setlocale (LC_ALL, "");
 	bindtextdomain (PACKAGE, PACKAGE_LOCALE_DIR);
@@ -886,7 +912,7 @@ main (int argc, char *argv[])
 	menu = gtk_menu_new ();
 	menu_radio_on = gtk_menu_item_new_with_label (_("Switch IR on"));
 	menu_radio_off = gtk_menu_item_new_with_label (_("Switch IR off"));
-	menu_vcard = gtk_menu_item_new_with_label (_("Send vcard"));
+	menu_vcard = gtk_menu_item_new_with_label (_("Send vCard"));
 	menu_control = gtk_menu_item_new_with_label (_("Controls..."));
 	menu_remove = gtk_menu_item_new_with_label (_("Remove from dock"));
 	g_signal_connect (G_OBJECT
@@ -924,8 +950,7 @@ main (int argc, char *argv[])
 	gtk_menu_append (GTK_MENU (menu), menu_vcard);
 	gtk_menu_append (GTK_MENU (menu), menu_control);
 	gtk_menu_append (GTK_MENU (menu), menu_remove);
-	if (gpe_load_icons (my_icons) == FALSE)
-		exit (1);
+	
 	icon = gtk_image_new_from_pixbuf
 		(gpe_find_icon (radio_is_on ? "irda-on" : "irda-off"));
 	gdk_pixbuf_render_pixmap_and_mask
@@ -935,14 +960,15 @@ main (int argc, char *argv[])
 	gtk_widget_show (icon);
 	gpe_set_window_icon (window, "irda");
 	tooltips = gtk_tooltips_new ();
-	gtk_tooltips_set_tip
-		(GTK_TOOLTIPS (tooltips),
-		 window,
-		 _("This is the infrared communications control."), NULL);
-	g_signal_connect (G_OBJECT
-			  (window),
-			  "button-press-event", G_CALLBACK (clicked), NULL);
+	gtk_tooltips_set_tip (GTK_TOOLTIPS (tooltips),
+		                  window,
+		                  _("This is the infrared communications control."), 
+	                      NULL);
+	gtk_object_set_data(GTK_OBJECT(window),"tooltips",tooltips);
+	g_signal_connect (G_OBJECT(window),
+			          "button-press-event", G_CALLBACK (clicked), NULL);
 	gtk_widget_add_events (window, GDK_BUTTON_PRESS_MASK);
+    g_signal_connect (G_OBJECT (window), "configure-event", G_CALLBACK (external_event), NULL);
 	gtk_container_add (GTK_CONTAINER (window), icon);
 	dpy = GDK_WINDOW_XDISPLAY (window->window);
 	gtk_widget_show (window);
